@@ -36,6 +36,7 @@ signals:
 public slots:
     void okButtonClicked();
     void storelastSearchToggled(int state);
+    void orientationChanged();
 
 private:
     QSettings          *settings;
@@ -45,6 +46,7 @@ private:
     QCheckBox   *storelastSearchBox;
     QCheckBox   *prefillSearchBox;
     QWidget *parent;
+    QPushButton *okButton;
 };
 
 #endif // CONFIGDIALOG_H
