@@ -15,15 +15,15 @@
     </message>
     <message>
         <location filename="mainwindow.cpp" line="40"/>
-        <location filename="mainwindow.cpp" line="126"/>
-        <location filename="mainwindow.cpp" line="285"/>
+        <location filename="mainwindow.cpp" line="137"/>
+        <location filename="mainwindow.cpp" line="330"/>
         <source>Enable GPS</source>
         <oldsource>Toggle GPS</oldsource>
         <translation>GPS einschalten</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="45"/>
-        <location filename="mainwindow.cpp" line="341"/>
+        <location filename="mainwindow.cpp" line="393"/>
         <source>Donate</source>
         <translation>Spenden</translation>
     </message>
@@ -40,9 +40,9 @@
     <message>
         <location filename="mainwindow.cpp" line="61"/>
         <location filename="mainwindow.cpp" line="62"/>
-        <location filename="mainwindow.cpp" line="246"/>
-        <location filename="mainwindow.cpp" line="247"/>
-        <location filename="mainwindow.cpp" line="717"/>
+        <location filename="mainwindow.cpp" line="291"/>
+        <location filename="mainwindow.cpp" line="292"/>
+        <location filename="mainwindow.cpp" line="824"/>
         <source>please select</source>
         <translation>bitte wählen</translation>
     </message>
@@ -61,13 +61,13 @@
         <translation type="obsolete">- bahn.de: absturz problem behoben&lt;br&gt;- kalender auswahl verbessert&lt;br&gt;- abfahrt/ankuft knopf verbessert</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="314"/>
+        <location filename="mainwindow.cpp" line="359"/>
         <source>Arrival time</source>
         <translation>Ankunft</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="89"/>
-        <location filename="mainwindow.cpp" line="310"/>
+        <location filename="mainwindow.cpp" line="355"/>
         <source>Departure time</source>
         <translation>Abfahrt</translation>
     </message>
@@ -87,13 +87,13 @@
         <translation>Suchen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="122"/>
-        <location filename="mainwindow.cpp" line="291"/>
+        <location filename="mainwindow.cpp" line="133"/>
+        <location filename="mainwindow.cpp" line="336"/>
         <source>Disable GPS</source>
         <translation>GPS ausschalten</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="153"/>
+        <location filename="mainwindow.cpp" line="164"/>
         <source>Welcome to a new version of fahrplan this has changed</source>
         <translation>Willkommen bei einer neuen Version von Fahrplan, dies ist neu</translation>
     </message>
@@ -106,22 +106,22 @@
         <translation type="obsolete">-bahn.de: fehler mit gps suche behoben&lt;br&gt;- Geburtstags Kalender wird nun nicht mehr als wählbarer kalender angezeigt.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="252"/>
+        <location filename="mainwindow.cpp" line="297"/>
         <source>not supported</source>
         <translation>nicht unterstützt</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="274"/>
+        <location filename="mainwindow.cpp" line="319"/>
         <source>&lt;br&gt;GPS is now available!&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist nun verfügbar!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="286"/>
+        <location filename="mainwindow.cpp" line="331"/>
         <source>&lt;br&gt;GPS is now &lt;b&gt;disabled&lt;/b&gt;&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;aus&lt;/b&gt;&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="292"/>
+        <location filename="mainwindow.cpp" line="337"/>
         <source>&lt;br&gt;GPS is now &lt;b&gt;enabled&lt;/b&gt;&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;an&lt;/b&gt;&lt;br&gt;</translation>
     </message>
@@ -130,7 +130,7 @@
         <translation type="obsolete">Verbindung: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="483"/>
+        <location filename="mainwindow.cpp" line="556"/>
         <source> to </source>
         <translation> nach </translation>
     </message>
@@ -168,14 +168,15 @@
         <translation type="obsolete">- sbb.ch: fehler im parser behoben</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="342"/>
+        <location filename="mainwindow.cpp" line="394"/>
         <source>Thank you for Donating!</source>
-        <translation>Danke fürs spenden!</translation>
+        <translation>Danke fürs Spenden!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="348"/>
-        <source>by smurfy (maemo@smurfy.de)&lt;br&gt;Version </source>
-        <translation>von smurfy (maemo@smurfy.de)&lt;br&gt;Version </translation>
+        <location filename="mainwindow.cpp" line="400"/>
+        <source>by smurfy (maemo@smurfy.de)&lt;br&gt;and CaCO3 (george@ruinelli.ch)&lt;br&gt;Version </source>
+        <oldsource>by smurfy (maemo@smurfy.de) &amp; CaCO3 (george@ruinelli.ch)&lt;br&gt;Version </oldsource>
+        <translation>von smurfy (maemo@smurfy.de)&lt;br&gt;und CaCO3 (george@ruinelli.ch)&lt;br&gt;Version </translation>
     </message>
     <message>
         <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
@@ -196,82 +197,91 @@
         <translation type="obsolete">&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="348"/>
+        <location filename="mainwindow.cpp" line="400"/>
         <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;DB&lt;/b&gt;, &lt;b&gt;MVV&lt;/b&gt;, &lt;b&gt;SBB&lt;/b&gt;, &lt;b&gt;ÖBB&lt;/b&gt;, &lt;b&gt;Rejseplanen.dk&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
         <translation>&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;DB&lt;/b&gt;, &lt;b&gt;MVV&lt;/b&gt;, &lt;b&gt;SBB&lt;/b&gt;, &lt;b&gt;ÖBB&lt;/b&gt;, &lt;b&gt;Rejseplanen.dk&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="350"/>
+        <location filename="mainwindow.cpp" line="402"/>
         <source>About Fahrplan</source>
         <translation>Über Fahrplan</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="377"/>
+        <location filename="mainwindow.cpp" line="440"/>
         <source>&lt;br&gt;Details already loading, please wait.&lt;br&gt;</source>
         <translation>&lt;br&gt;Details werden bereits geladen, bitte warten.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="391"/>
+        <location filename="mainwindow.cpp" line="459"/>
         <source>&lt;br&gt;Error opening the details.&lt;br&gt;</source>
         <translation>&lt;br&gt;Beim öffnen der Details ist ein Fehler aufgetreten.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="397"/>
+        <location filename="mainwindow.cpp" line="465"/>
         <source>Details</source>
         <translation>Details</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="406"/>
         <source>Add to calendar</source>
-        <translation>In Kalender eintragen</translation>
+        <translation type="obsolete">In Kalender eintragen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="488"/>
+        <location filename="mainwindow.cpp" line="474"/>
+        <source>Add to default calendar</source>
+        <translation>In Standardkal. eintragen</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="479"/>
+        <source>Add to a calendar</source>
+        <translation>In einen Kalender eintragen</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="561"/>
         <source>&lt;br&gt;&lt;b&gt;Duration: &lt;/b&gt;</source>
         <translation>&lt;br&gt;&lt;b&gt;Dauer: &lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="523"/>
+        <location filename="mainwindow.cpp" line="601"/>
         <source>&lt;br&gt;No results found.&lt;br&gt;</source>
         <translation>&lt;br&gt;Keine Ergebnisse gefunden.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="542"/>
+        <location filename="mainwindow.cpp" line="620"/>
         <source>Results</source>
         <translation>Ergebnis</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="559"/>
+        <location filename="mainwindow.cpp" line="644"/>
         <source>to</source>
         <translation>nach</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="570"/>
+        <location filename="mainwindow.cpp" line="655"/>
         <source>Earlier</source>
         <translation>Früher</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="576"/>
+        <location filename="mainwindow.cpp" line="661"/>
         <source>Later</source>
         <translation>Später</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="589"/>
+        <location filename="mainwindow.cpp" line="674"/>
         <source> transfer</source>
-        <translation> umstieg</translation>
+        <translation> Umstieg</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="592"/>
+        <location filename="mainwindow.cpp" line="677"/>
         <source> transfers</source>
-        <translation> umstiege</translation>
+        <translation> Umstiege</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="611"/>
+        <location filename="mainwindow.cpp" line="709"/>
         <source>&lt;br&gt;OnTime</source>
         <translation>&lt;br&gt;Pünktlich</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="747"/>
+        <location filename="mainwindow.cpp" line="863"/>
         <source>&lt;br&gt;Please select a from and to station and make sure they are not the same.&lt;br&gt;</source>
         <translation>&lt;br&gt;Bitte zwei verschiedene Haltestellen wählen.&lt;br&gt;</translation>
     </message>
@@ -284,58 +294,58 @@
         <translation>Ziel Kalender wählen</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="159"/>
+        <location filename="calendardialog.cpp" line="162"/>
         <source>Private</source>
         <translation>Privat</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="175"/>
+        <location filename="calendardialog.cpp" line="221"/>
         <source>Journey: </source>
         <translation>Verbindung: </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="175"/>
-        <location filename="calendardialog.cpp" line="176"/>
+        <location filename="calendardialog.cpp" line="221"/>
+        <location filename="calendardialog.cpp" line="222"/>
         <source> to </source>
         <translation> nach </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="184"/>
+        <location filename="calendardialog.cpp" line="230"/>
         <source>Duration: </source>
         <translation>Dauer: </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="221"/>
+        <location filename="calendardialog.cpp" line="267"/>
         <source>
 
 (added by fahrplan app, please recheck informations before travel.)</source>
         <translation>
 
-(hinzugefuegt von Fahrplan, bitte vor Fahrantritt daten erneut pruefen)</translation>
+(Hinzugefügt von Fahrplan, bitte vor Fahrantritt Daten erneut prüfen)</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="252"/>
+        <location filename="calendardialog.cpp" line="300"/>
         <source>&lt;br&gt;Entry already exists!&lt;br&gt;</source>
         <translation>&lt;br&gt;Eintrag existiert bereits!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="254"/>
+        <location filename="calendardialog.cpp" line="302"/>
         <source>&lt;br&gt;An error occured while adding the entry!&lt;br&gt;</source>
-        <translation>&lt;br&gt;Beim hinzufügen ist ein Fehler aufgetreten!&lt;br&gt;</translation>
+        <translation>&lt;br&gt;Beim Hinzufügen ist ein Fehler aufgetreten!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="100"/>
-        <location filename="calendardialog.cpp" line="231"/>
+        <location filename="calendardialog.cpp" line="103"/>
+        <location filename="calendardialog.cpp" line="279"/>
         <source>&lt;br&gt;Entry is in the past!&lt;br&gt;</source>
         <translation>&lt;br&gt;Eintrag ist in der Vergangenheit!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="250"/>
+        <location filename="calendardialog.cpp" line="298"/>
         <source>&lt;br&gt;Entry added to the </source>
         <translation>&lt;br&gt;Eintrag wurde zum </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="250"/>
+        <location filename="calendardialog.cpp" line="298"/>
         <source> calendar.&lt;br&gt;</source>
         <translation> Kalender hinzugefügt.&lt;br&gt;</translation>
     </message>
@@ -355,12 +365,12 @@
     <message>
         <location filename="configdialog.cpp" line="41"/>
         <source>Store last searched stations</source>
-        <translation>zuletzt verwendete Haltestellen speichern</translation>
+        <translation>Zuletzt verwendete Haltestellen speichern</translation>
     </message>
     <message>
         <location filename="configdialog.cpp" line="47"/>
         <source>Prefill last searched station</source>
-        <translation>letzte Haltestellen automatisch füllen</translation>
+        <translation>Letzte Haltestellen automatisch füllen</translation>
     </message>
     <message>
         <location filename="configdialog.cpp" line="53"/>
@@ -383,9 +393,8 @@
         <translation>MVV - Deutschland</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="71"/>
         <source>SBB Legacy - Swiss</source>
-        <translation>SBB Alt - Schweiz</translation>
+        <translation type="obsolete">SBB Alt - Schweiz</translation>
     </message>
     <message>
         <location filename="configdialog.cpp" line="75"/>
@@ -432,27 +441,27 @@
 <context>
     <name>parser131500ComAu</name>
     <message>
-        <location filename="parser_131500comau.cpp" line="95"/>
+        <location filename="parser_131500comau.cpp" line="97"/>
         <source>All, except School Buses</source>
         <translation>Alles, ausser Schulbusse</translation>
     </message>
     <message>
-        <location filename="parser_131500comau.cpp" line="96"/>
+        <location filename="parser_131500comau.cpp" line="98"/>
         <source>Regular Buses</source>
         <translation>Normale Busse</translation>
     </message>
     <message>
-        <location filename="parser_131500comau.cpp" line="97"/>
+        <location filename="parser_131500comau.cpp" line="99"/>
         <source>Trains</source>
         <translation>Züge</translation>
     </message>
     <message>
-        <location filename="parser_131500comau.cpp" line="98"/>
+        <location filename="parser_131500comau.cpp" line="100"/>
         <source>Ferries</source>
         <translation>Fähren</translation>
     </message>
     <message>
-        <location filename="parser_131500comau.cpp" line="99"/>
+        <location filename="parser_131500comau.cpp" line="101"/>
         <source>STA School Bus</source>
         <translation>Schulbusse</translation>
     </message>
@@ -460,74 +469,74 @@
 <context>
     <name>parserHafasXml</name>
     <message>
-        <location filename="parser_hafasxml.cpp" line="159"/>
+        <location filename="parser_hafasxml.cpp" line="172"/>
         <source>Internal Error occured!</source>
         <translation>Interner Fehler!</translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="343"/>
+        <location filename="parser_hafasxml.cpp" line="356"/>
         <source>All</source>
         <translation>Alle</translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="344"/>
+        <location filename="parser_hafasxml.cpp" line="357"/>
         <source>All without ICE</source>
         <translation>Alle ohne ICE</translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="345"/>
+        <location filename="parser_hafasxml.cpp" line="358"/>
         <source>Only local transport</source>
         <translation>Nur Nahverkehr</translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="346"/>
+        <location filename="parser_hafasxml.cpp" line="359"/>
         <source>Local transport without S-Bahn</source>
         <translation>Nur Nahverkehr ohne S-Bahn</translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="582"/>
-        <location filename="parser_hafasxml.cpp" line="588"/>
+        <location filename="parser_hafasxml.cpp" line="595"/>
+        <location filename="parser_hafasxml.cpp" line="601"/>
         <source>Platform </source>
-        <translation>Gleis</translation>
+        <translation>Gleis </translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="584"/>
-        <location filename="parser_hafasxml.cpp" line="590"/>
+        <location filename="parser_hafasxml.cpp" line="597"/>
+        <location filename="parser_hafasxml.cpp" line="603"/>
         <source>on</source>
         <translation>am</translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="636"/>
         <location filename="parser_hafasxml.cpp" line="649"/>
+        <location filename="parser_hafasxml.cpp" line="662"/>
         <source>Walk for </source>
         <translation>Zu Fuss für </translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="636"/>
-        <location filename="parser_hafasxml.cpp" line="639"/>
-        <location filename="parser_hafasxml.cpp" line="642"/>
-        <location filename="parser_hafasxml.cpp" line="645"/>
         <location filename="parser_hafasxml.cpp" line="649"/>
+        <location filename="parser_hafasxml.cpp" line="652"/>
+        <location filename="parser_hafasxml.cpp" line="655"/>
+        <location filename="parser_hafasxml.cpp" line="658"/>
+        <location filename="parser_hafasxml.cpp" line="662"/>
         <source> min.</source>
         <translation>min.</translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="639"/>
+        <location filename="parser_hafasxml.cpp" line="652"/>
         <source>Use a Bike for </source>
         <translation>Per Fahrrad für </translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="642"/>
+        <location filename="parser_hafasxml.cpp" line="655"/>
         <source>Use a car for </source>
         <translation>Per Auto für </translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="645"/>
+        <location filename="parser_hafasxml.cpp" line="658"/>
         <source>Take a taxi for </source>
         <translation>Per Taxi für </translation>
     </message>
     <message>
-        <location filename="parser_hafasxml.cpp" line="688"/>
+        <location filename="parser_hafasxml.cpp" line="701"/>
         <source>d</source>
         <translation>t</translation>
     </message>
@@ -563,22 +572,22 @@
 <context>
     <name>parserMvvDe</name>
     <message>
-        <location filename="parser_mvvde.cpp" line="313"/>
+        <location filename="parser_mvvde.cpp" line="315"/>
         <source>Walk</source>
         <translation>Laufen</translation>
     </message>
     <message>
-        <location filename="parser_mvvde.cpp" line="314"/>
+        <location filename="parser_mvvde.cpp" line="316"/>
         <source>S-Bahn</source>
         <translation>S-Bahn</translation>
     </message>
     <message>
-        <location filename="parser_mvvde.cpp" line="315"/>
+        <location filename="parser_mvvde.cpp" line="317"/>
         <source>U-Bahn</source>
         <translation>U-Bahn</translation>
     </message>
     <message>
-        <location filename="parser_mvvde.cpp" line="316"/>
+        <location filename="parser_mvvde.cpp" line="318"/>
         <source>Tram</source>
         <translation>Tram</translation>
     </message>
@@ -645,7 +654,7 @@
         <translation>Suchen</translation>
     </message>
     <message>
-        <location filename="selectstationdialog.cpp" line="147"/>
+        <location filename="selectstationdialog.cpp" line="175"/>
         <source>Select a station</source>
         <translation>Haltestelle wählen</translation>
     </message>
