@@ -22,6 +22,19 @@ QStringList fahrplanUtils::reverseQStringList(const QStringList &list)
     return reversedList;
 }
 
+QString fahrplanUtils::leadingZeros(int number, int presision)
+{
+    QString s;
+    s.setNum(number);
+    s = s.toUpper();
+    presision -= s.length();
+    while(presision>0){
+        s.prepend('0');
+        presision--;
+    }
+    return s;
+}
+
 /*
  * Replace common used umlaut chars to a maybe wrong but
  * readable format (used for calendar export)
