@@ -25,8 +25,21 @@ parserHafasXml::parserHafasXml(QObject *parent)
      Q_UNUSED(parent);
      http = new QHttp(this);
 
-     connect(http, SIGNAL(requestFinished(int,bool)),
-             this, SLOT(httpRequestFinished(int,bool)));
+     QNetworkAccessManager *NetworkManager = new QNetworkAccessManager(this);
+     QNetworkRequest request;
+
+     connect(http, SIGNAL(requestFinished(int,bool)), this, SLOT(httpRequestFinished(int,bool)));
+     connect(http, SIGNAL(dataReadProgress(int,int)), this, SLOT(httpDataReadProgress(int,int)));
+
+     connect(NetworkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(replyFinished(QNetworkReply*)));
+
+//     QNetworkReply *reply = NetworkManager->get(request);
+//     connect(NetworkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(replyFinished(QNetworkReply*)));
+//     connect(reply, SIGNAL(readyRead()), this, SLOT(slotReadyRead()));
+//      connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+//      connect(reply, SIGNAL(sslErrors(QList<QSslError>)), this, SLOT(slotSslErrors(QList<QSslError>)));
+
+
 
      //baseUrl = "http://fahrplan.oebb.at/bin/query.exe"; //OEB (fully operational/no RT) //no xmlhandle, detaildate already present!
      //baseUrl = "http://hafas.bene-system.com/bin/query.exe"; //hafas dev?? system? / no gps
@@ -767,10 +780,21 @@ QStringList parserHafasXml::getStationsByName(QString stationName)
     postData.append(stationName);
     postData.append("\" t=\"ST\" /></MLcReq></ReqC>");
 
+    qDebug() << "parserHafasXml::getStationsByName";
+
     QUrl url(baseUrl);
 
     http->setHost(url.host(), QHttp::ConnectionModeHttp, url.port() == -1 ? 0 : url.port());
 
+
+//    request.setUrl(url);
+//    request.setRawHeader("User-Agent", "MyOwnBrowser 1.0");
+
+
+
+
+
+
     filebuffer = new QBuffer();
 
     if (!filebuffer->open(QIODevice::WriteOnly))
@@ -784,6 +808,14 @@ QStringList parserHafasXml::getStationsByName(QString stationName)
 
     currentRequestId = http->request(header, postData, filebuffer);
 
+
+//    request.setHeader(
+//    request.
+
+//    NetworkManager->post(request, postData);
+
+
+
     loop.exec();
 
     filebuffer->close();
