@@ -25,8 +25,8 @@ parserSbbCh::parserSbbCh(QObject *parent)
     Q_UNUSED(parent);
     http = new QHttp(this);
 
-    connect(http, SIGNAL(requestFinished(int,bool)),
-            this, SLOT(httpRequestFinished(int,bool)));
+    connect(http, SIGNAL(requestFinished(int,bool)), this, SLOT(httpRequestFinished(int,bool)));
+    connect(http, SIGNAL(dataReadProgress(int,int)), this, SLOT(httpDataReadProgress(int,int)));
 }
 
 bool parserSbbCh::supportsGps()
@@ -40,6 +40,8 @@ QStringList parserSbbCh::getStationsByName(QString stationName)
     QByteArray postData = "queryPageDisplayed=yes&start=%BB%A0Search+connection&REQ0JourneyStopsS0A=1&REQ0JourneyStopsS0G=";
     postData.append(stationName);
 
+    qDebug() << "SBBch: getStationsByName";
+
     QUrl url("http://fahrplan.sbb.ch/bin/query.exe/en");
 
     http->setHost(url.host(), QHttp::ConnectionModeHttp, url.port() == -1 ? 0 : url.port());
