@@ -52,6 +52,16 @@ selectStationDialog::selectStationDialog(QValueButton *sender, QGeoPositionInfo
 
     gpsButton    = new QPushButton(tr("GPS"));
     searchButton = new QPushButton(tr("Search"));
+
+    progressbar = new QDial();
+
+    progressbar->setEnabled(false);
+    progressbar->setWrapping(true);
+    progressbar->hide();
+
+    timer = new QTimer(this);
+    connect(timer, SIGNAL(timeout()), this, SLOT(updateProgress()));
+
     connect(searchButton, SIGNAL(clicked(bool)), this, SLOT(searchButtonClicked(bool)));
     connect(gpsButton, SIGNAL(clicked(bool)), this, SLOT(gpsButtonClicked(bool)));
 
@@ -70,6 +80,7 @@ selectStationDialog::selectStationDialog(QValueButton *sender, QGeoPositionInfo
 
     searchboxCombo->setFixedHeight(72);
     searchboxText->setFixedHeight(72);
+    progressbar->setFixedWidth(72);
 
     QGridLayout *layout = new QGridLayout();
 
@@ -89,13 +100,14 @@ void selectStationDialog::orientationChanged()
 {
     QRect screenGeometry = QApplication::desktop()->screenGeometry();
     QGridLayout *layout = (QGridLayout*)this->layout();
-    if (screenGeometry.width() > screenGeometry.height())
+
+    if (screenGeometry.width() > screenGeometry.height()) //landscape
     {
         gpsButton->setFixedWidth(210);
         searchButton->setFixedWidth(210);
 
-        layout->addWidget(gpsButton, 0, 1);
-        layout->addWidget(searchButton, 1, 1);
+        layout->addWidget(gpsButton, 0, 2);
+        layout->addWidget(searchButton, 1, 2);
         if (settings->value("storelastsearch", true).toBool() ==  true)
         {
             layout->addWidget(searchboxCombo, 0, 0, 0, 1);
@@ -103,7 +115,9 @@ void selectStationDialog::orientationChanged()
         {
             layout->addWidget(searchboxText, 0, 0, 0, 1);
         }
-    } else {
+        layout->addWidget(progressbar, 0, 1, 0, 1);
+
+    } else { //portrait
         gpsButton->setMinimumWidth(210);
         searchButton->setMinimumWidth(210);
 
@@ -116,9 +130,23 @@ void selectStationDialog::orientationChanged()
         {
             layout->addWidget(searchboxText, 0, 0, 1, 0);
         }
+        layout->addWidget(progressbar, 0, 1);
     }
 }
 
+
+
+void selectStationDialog::updateProgress(){   
+    progress++;
+    qDebug() << progress;
+    progressbar->setValue((progress*5) % 100);
+
+    if(progress > 250){ // 20ms * 50 * 5 = 5 sec
+        backendParser->httpRequestTimeout();
+    }
+}
+
+
 void selectStationDialog::showSelector(QStringList items)
 {
     //If only one entry found we directly use it.
@@ -149,6 +177,8 @@ void selectStationDialog::showSelector(QStringList items)
     w->show();
 }
 
+
+
 void selectStationDialog::stationSelected(QString value)
 {
     if (value != "")
@@ -158,6 +188,8 @@ void selectStationDialog::stationSelected(QString value)
     }
 }
 
+
+
 void selectStationDialog::searchButtonClicked(bool checked)
 {
     Q_UNUSED(checked);
@@ -172,13 +204,23 @@ void selectStationDialog::searchButtonClicked(bool checked)
         str = searchboxCombo->currentText();
     }
 
+    progress=0;
+    progressbar->show();
+    timer->start(20); //start timer with 20ms interval
+
     result = backendParser->getStationsByName(str);
 
+    progressbar->hide();
+    timer->stop();
+
     searchButton->setEnabled(true);
 
+
     if (result.count() > 0)
     {
         showSelector(result);
+    } else if(progress>250){
+         QMaemo5InformationBox::information(this, "<br>No response from server.<br>", QMaemo5InformationBox::DefaultTimeout);
     } else
     {
         QMaemo5InformationBox::information(this, "<br>Station not found.<br>", QMaemo5InformationBox::DefaultTimeout);
@@ -200,8 +242,15 @@ void selectStationDialog::gpsButtonClicked(bool checked)
 
         QStringList result;
 
+        progress=0;
+        progressbar->show();
+        timer->start(20); //start timer with 20ms interval
+
         result = backendParser->getStationsByGPS(latitude, longitude);
 
+        progressbar->hide();
+        timer->stop();
+
         gpsButton->setEnabled(true);
 
         if (result.count() > 0)
@@ -247,3 +296,10 @@ void selectStationDialog::gpsButtonClicked(bool checked)
         }
     }
 }
+
+
+void selectStationDialog::closeEvent(QCloseEvent *event)
+{
+    Q_UNUSED(event);
+    timer->stop(); //stop timer in case it is still running
+}
